@@ -19,13 +19,14 @@ from importlib import import_module
 import six
 import click
 
+from rqalpha.utils.i18n import gettext as _
 from rqalpha.utils.config import dump_config
 from .entry import cli
 
 
 @cli.command(context_settings=dict(
     ignore_unknown_options=True,
-))
+), help=_("Mod management command"))
 @click.help_option('-h', '--help')
 @click.argument('cmd', nargs=1, type=click.Choice(['list', 'enable', 'disable']))
 @click.argument('params', nargs=-1)
@@ -60,7 +61,7 @@ def mod(cmd, params):
         ]
 
         six.print_(tabulate(table, headers=headers, tablefmt="psql"))
-        six.print_("You can use `rqalpha mod list/install/uninstall/enable/disable` to manage your mods")
+        six.print_("You can use `rqalpha mod list/enable/disable` to manage your mods")
 
     def change_mod_status(mod_list, enabled):
         for mod_name in mod_list:
@@ -75,7 +76,7 @@ def mod(cmd, params):
             try:
                 import_module(module_name)
             except ImportError:
-                print("can not find mod [{}] !, ignore".format(mod_name))
+                print("can not find mod [{}], ignored".format(mod_name))
                 continue
 
             from rqalpha.utils.config import user_mod_conf_path, load_yaml
