@@ -30,7 +30,7 @@ from rqalpha.const import MATCHING_TYPE, ORDER_STATUS, POSITION_EFFECT, EXECUTIO
 from rqalpha.model.order import Order
 from rqalpha.environment import Environment
 
-from .matcher import DefaultMatcher, AbstractMatcher, CounterPartyOfferMatcher
+from .matcher import DefaultBarMatcher, AbstractMatcher, CounterPartyOfferMatcher, DefaultTickMatcher
 
 
 class SimulationBroker(AbstractBroker, Persistable):
@@ -51,6 +51,7 @@ class SimulationBroker(AbstractBroker, Persistable):
         if self._mod_config.matching_type == MATCHING_TYPE.COUNTERPARTY_OFFER:
             for instrument_type in INSTRUMENT_TYPE:
                 self.register_matcher(instrument_type, CounterPartyOfferMatcher(self._env, self._mod_config))
+
         # 该事件会触发策略的before_trading函数
         self._env.event_bus.add_listener(EVENT.BEFORE_TRADING, self.before_trading)
         # 该事件会触发策略的handle_bar函数
@@ -68,7 +69,10 @@ class SimulationBroker(AbstractBroker, Persistable):
         try:
             return self._matchers[instrument_type]
         except KeyError:
-            return self._matchers.setdefault(instrument_type, DefaultMatcher(self._env, self._mod_config))
+            if self._env.config.base.frequency == "tick":
+                return self._matchers.setdefault(instrument_type, DefaultTickMatcher(self._env, self._mod_config))
+            else:
+                return self._matchers.setdefault(instrument_type, DefaultBarMatcher(self._env, self._mod_config))
 
     def register_matcher(self, instrument_type, matcher):
         # type: (INSTRUMENT_TYPE, AbstractMatcher) -> None
